{% extends "base.html" %} {% block content %}

#### {{page_title}}

##### {{'Viewing results ' + (res_start + 1)|string + ' to ' + (res_start + res_actual)|string + '.'}} {% if res_start > res_limit %} {{'First ' + res_limit|string}} {% else %} {% endif %} {% if res_start > 0 and res_actual == res_limit %} {{" | "}} {% endif %} {% if res_actual == res_limit %}

status | summary {% for kwarg in history_kwargs %} {% set this_kwarg = kwarg + ' (UTC)' if kwarg == 'uuid' else kwarg %} | {{this_kwarg}} {% endfor %} |
--- | --- | --- | ---
{% for entry in history %} {% set rowstat = '' %} {% if entry[0] in ['PASS', 'DONE'] %} {% set rowstat = 'success' %} {% elif entry[0] in ['WARN', 'PEND'] %} {% set rowstat = 'warning' %} {% elif entry[0] == 'FAIL' %} {% set rowstat = 'danger' %} {% elif entry[0] == 'ERROR' %} {% set rowstat = 'active' %} {% else %} {% set rowstat = '' %} {% endif %}
{{entry[0]}} | {{entry[1]}} {% for kw in history_kwargs %} | {{entry[2].get(kw)}} {% endfor %} {# boolean in entry[3] saying if it's a check or not #} {% if entry[3] == True %} | Result {% endif %} {% if 'uuid' in entry[2] %} | JSON {% else %} | Error {% endif %}
{% endfor %}

{% endblock %}